<?php
/**
 * Browse messages
 *
 * Copyright 2007 Obala d.o.o. (www.obala.si)
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/news/LICENSE.
 *
 * $Id: browse.php 304 2008-01-30 18:50:37Z duck $
 *
 * @author Duck <duck@obala.net>
 * @package Usms
 */

require_once dirname(__FILE__) . '/lib/base.php';

$folder = Util::getFormData('folder', 'inbox');
$title = ($folder == 'sent') ? _("Sent") : $folder;
$page = Util::getGet('page', 0);
$actionID = Util::getFormData('actionID');
$browse_url = Util::addParameter(Horde::applicationUrl('browse.php'), array('folder' => $folder, 'page' => $page), false, false);

// Check that actions are not performad only on set, but delete_sent can
if ($actionID != null && $folder == 'sent' && $actionID != 'delete_sent') {
    $actionID = null;
    $notification->push(_("You cannot perform actions on your sent folder."), 'horde.warning');
}

// Perform actions
switch ($actionID) {
case 'move':

    $to = Util::getFormData('to', 'archive');
    $from = Util::getFormData('from', 'inbox');
    $id = Util::getFormData('id');
    if (!is_array($id)) {
        $id = array($id);
    }

    $result = $usms->moveMessage($id, $from, $to);
    if ($result instanceof PEAR_Error) {
        $notification->push($result->getMessage(), 'horde.error');
    } else {
        $notification->push(_("Message(s) moved"), 'horde.success');
    }

    header('Location: ' . Util::addParameter(Horde::applicationUrl('browse.php'), 'folder', $to), false);
    exit;

break;

case 'whitelist':
case 'blacklist':

    Usms::addFriend($user, $actionID);
    $notification->push(sprintf(_("User %s was added to your %s."), $user, _($actionID)), 'horde.success');

break;

case 'seen':
case 'unseen':
case 'markdeleted':
case 'undelete':

    switch ($actionID) {
    case 'unseen':
        $status = Usms::STATUS_UNSEEN;
        break;

    case 'markdeleted':
        $status = Usms::STATUS_DELETED;
        break;

    default:
        $status = Usms::STATUS_SEEN;
        break;
    }

    $id = Util::getFormData('id');
    if (!is_array($id)) {
        $id = array($id);
    }

    $result = $usms->changeStatus($id, $folder, $status);
    if ($result instanceof PEAR_Error) {
        $notification->push($result->getMessage(), 'horde.error');
    } else {
        $notification->push(_("Status changed"), 'horde.success');
    }

break;

case 'empty_trash':

    $result = $usms->emptyTrash($folder);
    if ($result instanceof PEAR_Error) {
        $notification->push($result->getMessage(), 'horde.error');
    } else {
        $notification->push(_("Trash was cleaned"), 'horde.success');
    }

break;

case 'delete':

    $id = Util::getFormData('id');
    $result = $usms->deleteMessage($id, $folder);
    if ($result instanceof PEAR_Error) {
        $notification->push($result->getMessage(), 'horde.error');
    } else {
        $notification->push(_("Message(s) deleted"), 'horde.success');
    }

break;

case 'delete_sent':

    $id = Util::getFormData('id');
    $user_to = Util::getFormData('user_to');
    $result = $usms->deleteSentMessage($id, $user_to);
    if ($result instanceof PEAR_Error) {
        $notification->push($result->getMessage(), 'horde.error');
    } else {
        $notification->push(_("Message(s) deleted"), 'horde.success');
    }

break;

}

/* Check for attributes */
if (($sortby = Util::getFormData('sortby')) !== null) {
    $prefs->setValue('sortby', $sortby);
} else {
    $sortby = $prefs->getValue('sortby');
}
if (($sortdir = Util::getFormData('sortdir')) !== null) {
    $prefs->setValue('sortdir', $sortdir);
} else {
    $sortdir = $prefs->getValue('sortdir');
}
if (($perpage = Util::getFormData('perpage')) !== null) {
    $prefs->setValue('perpage', $perpage);
} else {
    $perpage = $prefs->getValue('perpage');
}
if (($hide_deleted = Util::getFormData('hide_deleted')) !== null) {
    $prefs->setValue('hide_deleted', $hide_deleted);
} else {
    $hide_deleted = $prefs->getValue('hide_deleted');
}

$read_url = Util::addParameter(Horde::applicationUrl('read.php'), array('page' => $page, 'folder' => $folder));
$criteria = array('folder' => $folder,
                   'user' => Auth::getAuth(),
                   'hide_deleted' => $hide_deleted);

$rows = $usms->countMessages($criteria);

Horde::addScriptFile('usms.js', 'usms', true);
require USMS_TEMPLATES . '/common-header.inc';
require USMS_TEMPLATES . '/menu.inc';
require USMS_TEMPLATES . '/browse/header.php';

if ($rows == 0) {

    require USMS_TEMPLATES . '/browse/empty.php';

} else {

    require USMS_TEMPLATES . '/browse/message_headers.php';

    $messages = $usms->getMessages($criteria, $page * $perpage, $perpage);
    if ($messages instanceof PEAR_Error) {
        echo $messages->getDebugInfo();
        $messages = array();
    }

    foreach ($messages as $id => $row) {
        $row['date'] = Usms::format_datetime(Usms::index($row['id']));
        require USMS_TEMPLATES . '/browse/row.php';
    }

    if ($rows > $perpage) {
        require_once 'Horde/Variables.php';
        $pager = new Horde_UI_Pager('page',
                                    Variables::getDefaultVariables(),
                                    array('num' => $rows,
                                            'url' => 'browse.php',
                                            'perpage' => $perpage,
                                            'page_limit' => 10));
    }

    require USMS_TEMPLATES . '/browse/message_footers.php';
}

require USMS_TEMPLATES . '/browse/footer.php';
require $registry->get('templates', 'horde') . '/common-footer.inc';
