<?php
/**
 * USMS base class
 *
 * Copyright 2007 Obala d.o.o. (www.obala.si)
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/news/LICENSE.
 *
 * $Id: unixfs.php 297 2008-01-28 21:26:28Z duck $
 *
 * @author Duck <duck@obala.net>
 * @package Usms
 */
class Usms_Driver_unixfs extends Usms_Driver {

    /**
     * Delete sent message files
     *
     * @param intiger $id message id
     * @param string $user user owning the message
     */
    protected function _deleteSentMessage($id, $user)
    {
        register_shutdown_function(array(&$this, '_doGC'), $id, $user);
        touch($this->vfsPath(Auth::getAuth()) . '/newmsg');
    }

    /**
     * Mark users to have new messages
     *
     * @param string $user user to mark
     */
    protected function _writeNew($user, $num)
    {
        file_put_contents($this->vfsPath($user) . '/newmsg', $num);
    }

    /**
     * Return file path where to store message data
     *
     * @param intiger $user owner username
     * @param array $id message id
     * @param boolean $autocreate crete folder
     */
    public function vfsPath($user, $id = false, $autocreate = false)
    {
        // General dir
        if (empty($GLOBALS['conf']['vfs']['params']['vfsroot'])) {
            $path = Horde::getTempDir();
        } else {
            $path = $GLOBALS['conf']['vfs']['params']['vfsroot'] . '/.horde/usms';
        }

        // User path
        $user = md5($user);
        $path .= '/' . substr(str_pad($user, 2, 0, STR_PAD_LEFT), -2) . '/' . $user . '/';

        // Message path
        if ($id) {
            $path .= '/' . substr($id, 8, 2) . '/' . $id;
        }

        // Create dir if needed
        if ($autocreate && !file_exists($path)) {
            mkdir($path, 0777, true);
        }

        return $path . '/';
    }

    /**
     * Stores attaced file
     *
     * @param intiger $id message id
     * @param array  $file file to store
     * @param string $user user for wich we are storing
     */
    protected function _storeFile($id, $file, $user = false)
    {
        $file_name = 0;
        $path = $this->vfsPath($user, $id, true);
        if (file_exists($path . $file_name)) {
            $file_name++;
            if (file_exists($path . $file_name)) {
                $file_name++;
            }
        }

        return copy($file['tmp_name'], $path . $file_name);
    }

    /**
     * Stores body data
     *
     * @param intiger $id message id
     * @param array $data to be stored
     * @param string $user user for wich we are storing
     */
    protected function _storeBodyData($id, $data, $user)
    {
        $content = '<?php $info = ' . var_export($data, true) . ';';
        $file = $this->vfsPath($user, $id, true) . 'body.php';

        return file_put_contents($file, $content);
    }

    /**
     * Get body data
     *
     * @param intiger $id message id
     * @param string $user username
     */
    public function readBodyData($id, $user = null)
    {
        if ($user == null) {
            $user = Auth::getBareAuth();
        }

        if ((include($this->vfsPath($user, $id) . 'body.php')) === false) {
            return PEAR::raiseError(_("Cannot read message data"));
        }

        return $info;
    }

    /**
     * Delete message files
     *
     * @param mixed $ids Message ids
     * @param string $user User owner
     */
    public function _doGC($ids, $user)
    {
        if (is_array($ids)) {
            $paths = '';
            foreach ($ids as $id) {
                $paths .= $this->vfsPath($user, $id);
            }
        } else {
            $paths = $this->vfsPath($user, $ids);
        }

        system('rm -rf ' . $paths);
    }

    /**
     * copy file from one message to another
     *
     * @param intiger $form_id source message id
     * @param string $from_user source user
     * @param intiger $form_file source filename
     * @param intiger $to_id destination message id
     * @param string $to_user destination user
     */
    protected function _copyFile($from_id, $from_user, $file, $to_id, $to_user)
    {
        return copy($this->vfsPath($from_user, $from_id) . $file,
                    $this->vfsPath($to_user, $to_id, true) . $file);
    }

    /**
     * Mark users to have new data
     *
     * @param string $user user to mark
     */
    protected function _markNew($user = null)
    {
        if ($user == null) {
            $user = Auth::getBareAuth();
        }

        if (is_array($user)) {
            $query = 'SELECT COUNT(*), user_to FROM usms_inbox WHERE user_to IN ("' . implode('","', $user).  '") '
                    . ' AND status = ' . self::STATUS_UNSEEN . ' GROUP BY user_to';
            $msgs = $this->_db->getAll($query);
            foreach ($msgs as $count) {
                file_put_contents($this->vfsPath($count[1]) . '/newmsg', $count[0]);
            }
        } else {
            $query = 'SELECT COUNT(*) FROM usms_inbox WHERE user_to = ? AND status = ?';
            $msgs = $this->_db->getOne($query, array($user, self::STATUS_UNSEEN));
            file_put_contents($this->vfsPath($user) . '/newmsg', $msgs);
        }
    }

    /**
     * Return number users new messages
     *
     * @param string $user user to check
     */
    public function checkNew($user)
    {
        $path = $this->vfsPath($user) . '/newmsg';
        if (file_exists($path)) {
            return file_get_contents($path);
        } else {
            return 0;
        }
    }

    /**
     * Append namespace to cache key
     *
     * @param string $key Cache key
     */
    protected function _getCacheKey($key)
    {
        static $prefix;

        if ($prefix === null) {
            $path = $this->vfsPath(Auth::getAuth()) . '/newmsg';

            if (file_exists($path)) {
                $prefix = filemtime($path);
            } else {
                $prefix = '0';
            }
        }

        return 'folks_' . $prefix . '_' . $key;
    }

    /**
     * Append namespace to cache key
     *
     * @param string $key Cache key
     */
    protected function _expireCache($user)
    {
        touch($this->vfsPath($user) . '/newmsg');
    }
}
