<?php
/**
 * Compose message class
 *
 * Copyright 2007 Obala d.o.o. (www.obala.si)
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/news/LICENSE.
 *
 * $Id: Compose.php 311 2008-01-31 16:15:38Z duck $
 *
 * @author Duck <duck@obala.net>
 * @package Usms
 */

class Usms_Compose_Form extends Horde_Form {

    /**
     * Creator
     */
    public function __construct($vars, $title, $name = '')
    {
        parent::__construct($vars, $title, $name);

        $this->_submit = _("Send");
        $this->addHidden('', 'actionID', 'text', false, true);

        $this->addVariable(_("To user"), 'user_to', 'text', true, false, $this->_getAutocompleter(), array('', 32));

        $this->addVariable(_("Title"), 'title', 'text', true, false, false);

        if ($GLOBALS['prefs']->getValue('richtext')) {
            $editor = Horde_Editor::singleton('tinymce', array('id' => 'content'));
        }

        $this->addVariable(_("Content"), 'content', 'longtext', true, false, false, array('15', '70'));

        $this->addVariable(_("Priority"), 'priority', 'enum', false, false, false,
                                            array(array(Usms::PRIORITY_NORMAL => _("Normal"),
                                                                Usms::PRIORITY_LOW => _("Low"),
                                                                Usms::PRIORITY_HIGH => _("High"))));

        $this->addVariable(_("Request a Read Receipt"), 'notify', 'boolean', false);

        if ($GLOBALS['conf']['general']['attaches']) {
            if ($this->_vars->get('actionID') == 'forward') {
                $this->addVariable(_("The attacments of the original messages will be appended automaticaly"), 'description', 'description', false);
            } else {
                for ($i = 0; $i < $GLOBALS['conf']['general']['attaches']; $i++) {
                    $this->addVariable(sprintf(_("File %s"), ($i+1)), 'attachment' . $i, 'file', false, false);
                }
            }
        }
    }

    /**
     * Load autocomplete for friends list
     */
    private function _getAutocompleter()
    {
        $whitelist = Usms::getFriends();
        if (empty($whitelist) || !is_array($whitelist)) {
            $url = Horde::url($GLOBALS['registry']->get('webroot', 'horde') . '/services/prefs.php?group=lists&app=usms');
            return ' <a href="' . $url .'">' . _("Edit your friends list") .'</a>';
        }

        $groups = Usms::getGroups();

        Horde::addScriptFile('prototype.js', 'horde', true);
        Horde::addScriptFile('effects.js', 'horde', true);
        Horde::addScriptFile('controls.js', 'horde', true);

        $html = '<div id="friends" class="friends">';
        foreach ($whitelist as $friend) {
            $html .= '<a href="javascript:void(0)" onclick="addFriend(\'' . $friend . '\')">' . $friend . '</a><br />';
        }
        $html .= '<br /><a href="javascript:void(0)" onclick="showFriends(0)">' . _("Close") . '</a></div>';

        $html .= '<div id="groups" class="groups">';
        foreach ($groups as $group) {
            $html .= '<a href="javascript:void(0)" onclick="addGroup(\'' . $group . '\')">' . $group . '</a><br />';
        }
        $html .= '<br /><a href="javascript:void(0)" onclick="showGroups(0)">' . _("Close") . '</a></div>';


        $whitelist = Horde_Serialize::serialize(array_values($whitelist), SERIALIZE_JSON, NLS::getCharset());
        $groups = Horde_Serialize::serialize($groups, SERIALIZE_JSON, NLS::getCharset());

        $html .= '</div>
        <div id="user_to_list" class="autocomplete"></div>
        <script type="text/javascript">
        var whitelist = ' . $whitelist . ';
        var groups = ' . $groups . ';
        new Autocompleter.Local("user_to", "user_to_list", whitelist, {});
        </script>
        <a href="javascript:void(0)" onmouseover="showFriends(1)">' . _("Friends") . '</a> /
        <a href="javascript:void(0)" onmouseover="showGroups(1)">' . _("Groups") . '</a>
        ';

        return $html;
    }

}
