<?php
/**
 * Usms api
 *
 * Copyright 2007 Duck <duck@obala.net>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/folks/LICENSE.
 *
 * $Id: api.php 304 2008-01-30 18:50:37Z duck $
 *
 * @author Duck <duck@obala.net>
 * @package Usms
 */

$_services['compose'] = array(
    'args' => array('args' => 'array'),
    'type' => 'string'
);

$_services['countUnread'] = array(
    'args' => array('username', 'status'),
    'type' => 'string'
);

$_services['removeUserData'] = array(
    'args' => array('user' => 'string'),
    'type' => 'boolean'
);

$_services['addFriend'] = array(
    'args' => array('friend' => 'string', 'group' => 'string'),
    'type' => 'boolean'
);

$_services['getFriends'] = array(
    'args' => array('user' => 'string'),
    'type' => 'boolean'
);

$_services['getBlacklist'] = array(
    'args' => array('user' => 'string'),
    'type' => 'boolean'
);

$_services['show'] = array(
    'link' => '%application%/read.php?id=|id|'
);

$_services['getMessages'] = array(
    'args' => array('criteria' => 'array', 'from' => 'int', 'count' => 'int'),
    'type' => 'array'
);

$_services['countMessages'] = array(
    'args' => array('criteria' => 'array'),
    'type' => 'integer'
);

$_services['sendMessage'] = array(
    'args' => array('sendto' => 'array', 'info' => 'array'),
    'type' => 'integer'
);

$_services['deleteMessage'] = array(
    'args' => array('id' => 'array', 'folder' => 'string'),
    'type' => 'integer'
);

$_services['getMessage'] = array(
    'args' => array('id' => 'array', 'folder' => 'string'),
    'type' => 'integer'
);

/**
 * Add user to a friend list
 *
 * @param string $friend   Friend's usersame
 * @param string $group   Group to add friend to
 */
function _usms_addFriend($friend, $group)
{
    require_once dirname(__FILE__) . '/base.php';

    // We don't support groups in usms
    if ($group != _("Blacklist")) {
        $group = 'whitelist';
    } else {
        $group = 'blacklist';
    }

    return Usms::addFriend($friend, $group);
}

/**
 * Get user friedns
 */
function _usms_getFriends($user = null)
{
    require_once dirname(__FILE__) . '/Usms.php';

    $prefs = Prefs::singleton($GLOBALS['conf']['prefs']['driver'], 'usms', $user);

    return Usms::lists('whitelist');
}

/**
 * Get user blacklist
 */
function _usms_getBlacklist($user = null)
{
    require_once dirname(__FILE__) . '/Usms.php';

    return Usms::lists('blacklist', $user);
}

/**
 * Return a compose window link.
 *
 * @param array $args indexed array as parameters to add
 *
 * @return string  The link to the message composition screen.
 */
function _usms_compose($args)
{
    return Util::addParameter(Horde::applicationUrl('compose.php'), $args);
}

/**
 * Return number of unreded messages
 *
 * @param optional string $user Username to check
 *
 * @return intiger  The number of messages
 */
function _usms_countUnread($user = '')
{
    require_once dirname(__FILE__) . '/Usms.php';

    if (!$user) {
        $user = Auth::getAuth();
    }

    return Usms::checkNew($user);
}

/**
 * Send message
 *
 * @param mixes $sendto username to send message to
 * @param array $info Message data
 **/
function _usms_sendMessage($sendto, $info)
{
    require_once dirname(__FILE__) . '/base.php';

    return $GLOBALS['usms']->sendMessage($sendto, $info);
}

/**
 * Deletes a user and its data
 *
 * @param string $userId  The userId to delete.
 *
 * @return boolean  True on success or a PEAR_Error object on failure.
 */
function _usms_removeUserData($user)
{
    if (!Auth::isAdmin() && $user != Auth::getAuth()) {
        return PEAR::raiseError(_("You are not allowed to remove user data."));
    }

    require_once dirname(__FILE__) . '/base.php';

    $messages = $GLOBALS['usms']->getMessages(array('user' => $user));

    $ids = array();
    foreach ($messages as $message) {
        $ids[] = $message['id'];
    }

    return $GLOBALS['usms']->deleteMessage($ids, 'inbox', $user);
}

/**
 * List messages
 *
 * @param array $criteria Array of ad attributes match
 * @param intiger $from Start fetching from ad
 * @param intiger $count The number of ads to fetch
 *
 * @return array | PEAR_Error  True on success, PEAR_Error on failure.
 */
function _usms_getMessages($criteria = array(), $from = 0, $count = 0)
{
    require_once dirname(__FILE__) . '/base.php';

    return $GLOBALS['usms']->getMessages($criteria, $from, $count);
}

/**
 * Count messages
 *
 * @param array $criteria Array of ad attributes match
 *
 * @return integer | PEAR_Error  True on success, PEAR_Error on failure.
 */
function _usms_countMessages($criteria = array())
{
    require_once dirname(__FILE__) . '/base.php';

    return $GLOBALS['usms']->countMessages($criteria);
}

/**
 * Delete message
 *
 * @param intiger $id message id
 * @param string $folder folder name
 *
 * @return boolean  True on success or a PEAR_Error object on failure.
 */
function _usms_deleteMessage($ids, $folder)
{
    require_once dirname(__FILE__) . '/base.php';

    return $GLOBALS['usms']->deleteMessage($ids, $folder);
}

/**
 * Get a single message
 *
 * @param intiger $id message id
 * @param string $folder folder name
 *
 * @return boolean  True on success or a PEAR_Error object on failure.
 */
function _usms_getMessage($ids, $folder)
{
    require_once dirname(__FILE__) . '/base.php';

    return $GLOBALS['usms']->getMessage($id, $folder);
}
