<?php
/**
 * The Message script to delete a message.
 *
 * Copyright 2007-2008 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: incubator/oscar/report.php,v 1.7 2008/01/12 14:01:02 duck Exp $
 */

define('USMS_BASE', dirname(__FILE__));
require_once USMS_BASE . '/lib/base.php';

$title = _("Report message");
$id = Util::getFormData('id');
$return_url = Util::addParameter(Horde::applicationUrl('read.php'), 'id', $id);

// Get message
$message = $usms->getMessage($id);
if ($message instanceof PEAR_Error) {
    $notification->push($message->getMessage(), 'horde.error');
    header('Location: ' . Horde::applicationUrl('browse.php'));
    exit;
}

require_once 'Horde/Variables.php';
$vars = Variables::getDefaultVariables();
$form = new Horde_Form($vars, _("Do you really want to report this message?"),
                         'delete');
$form->setButtons(array(_("Report"), _("Cancel")));

$enum = array('advertisement' => _("Advertisement content"),
              'terms' => _("Terms and conditions infringement"),
              'offensive' => _("Offensive content"));

$form->addHidden('', 'id', 'text', true, true);
$vars->set('id', $id);

$form->addVariable(_("Title"), 'title', 'text', true, true);
$vars->set('title', $message['title']);

$form->addVariable(_("User"), 'user', 'text', true, true);
$vars->set('user', $message['user']);

$v = $form->addVariable(_("Report type"), 'type', 'radio', true, false, null, array($enum));
$v->setDefault('terms');
$id = Util::getFormData('id');

if ($form->validate()) {

    if (Util::getFormData('submitbutton') == _("Report") && $conf['auth']['admins']) {

        $body = _("Message") . ': ' . $vars->get('title') . "\n\n"
                . _("Id") . ': ' . $vars->get('id') . "\n\n"
                . _("User") . ': ' . $vars->get('user') . "\n\n"
                . $enum[$vars->get('type')] . "\n\n"
                . Auth::getAuth() . "\n\n"
                . $_SERVER["REMOTE_ADDR"];

        $result = $usms->sendMessage($conf['auth']['admins'],
                                    array('title' => _("Abuse report"), 'content' => $body),
                                    false);

        if ($result instanceof PEAR_Error) {
            $notification->push(_("Message was not reported.") . ' ' .
                                $result->getMessage(), 'horde.error');
        } else {
            $notification->push(_("Message reported."), 'horde.success');
        }
    } else {
        $notification->push(_("Message was not reported."), 'horde.warning');
    }
    header('Location: ' . $return_url);
    exit;
}

require USMS_TEMPLATES . '/common-header.inc';
require USMS_TEMPLATES . '/menu.inc';
$form->renderActive(null, null, null, 'post');
require $registry->get('templates', 'horde') . '/common-footer.inc';
