<?php
/**
 * Delete old messages
 *
 * $Id: delete_old_msgs.php 296 2008-01-28 21:07:22Z duck $
 *
 * Copyright Obala d.o.o. (www.obala.si)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Duck <duck@obala.net>
 * @package Usms
 */

define('AUTH_HANDLER', true);
define('HORDE_BASE', dirname(__FILE__) . '/../..');
define('USMS_BASE', HORDE_BASE . '/usms');

// Do CLI checks and environment setup first.
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment.
Horde_CLI::init();
$cli = &Horde_CLI::singleton();

// Load Folks.
require_once USMS_BASE . '/lib/base.php';

// We accept the user name on the command-line.
require_once 'Console/Getopt.php';
$ret = Console_Getopt::getopt(Console_Getopt::readPHPArgv(), 'h:u:p:d:',
                              array('help', 'username=', 'password=', 'days='));

if ($ret instanceof PEAR_Error) {
    $error = _("Couldn't read command-line options.");
    Horde::logMessage($error, __FILE__, __LINE__, PEAR_LOG_DEBUG);
    $cli->fatal($error);
}

// Show help and exit if no arguments were set.
list($opts, $args) = $ret;
if (!$opts) {
    showHelp();
    exit;
}

// Defaults/initialization.
$caption = '';

foreach ($opts as $opt) {
    list($optName, $optValue) = $opt;
    switch ($optName) {
    case 'u':
    case '--username':
        $username = $optValue;
        break;

    case 'p':
    case '--password':
        $password = $optValue;
        break;

    case 'd':
    case '--days':
        $days = (int)$optValue;
        break;

    case 'h':
    case '--help':
        showHelp();
        exit;
    }
}

// Login to horde if username & password are set.
if (!empty($username) && !empty($password)) {
    $auth = &Auth::singleton($conf['auth']['driver']);
    if (!$auth->authenticate($username, array('password' => $password))) {
        $error = _("Login is incorrect.");
        Horde::logMessage($error, __FILE__, __LINE__, PEAR_LOG_ERR);
        $cli->fatal($error);
    } else {
        $msg = sprintf(_("Logged in successfully as \"%s\"."), $username);
        Horde::logMessage($msg, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $cli->message($msg, 'cli.success');
    }
}

// Default days
if (empty($days)) {
    $days = 30;
}

// Connect to db
$dbconf = Horde::getDriverConfig('storage', 'sql');
$db = &DB::connect($dbconf);

// Get messages older than X days
$limit = $_SERVER['REQUEST_TIME'] - $days * 86400;
$query = 'SELECT id, user_to FROM usms_index WHERE id < ' . $limit . '00000000';
$msgs = $db->getAll($query);
if ($msgs instanceof PEAR_Error) {
    die($msgs->getMessage() . "\n");
}

if (empty($msgs)) {
    die(_("No messages found under selected criteria") . "\n");
}

foreach ($msgs as $message) {
    system('rm -rf ' . $usms->vfsPath($message[1], $message[2]));
}

$query = 'DELETE FROM usms_index WHERE id < ' . $limit;
$msgs = $db->getAll($query);
if ($msgs instanceof PEAR_Error) {
    die($msgs->getMessage() . "\n");
}

/**
 * Show the command line arguments that the script accepts.
 */
function showHelp()
{
    global $cli;

    $cli->writeln(sprintf(_("Usage: %s [OPTIONS]..."), basename(__FILE__)));
    $cli->writeln();
    $cli->writeln(_("Mandatory arguments to long options are mandatory for short options too."));
    $cli->writeln();
    $cli->writeln(_("-h, --help                   Show this help"));
    $cli->writeln(_("-d, --days                   Number of days the message must be old"));
    $cli->writeln(_("-u, --username[=username]    Horde login username"));
    $cli->writeln(_("-p, --password[=password]    Horde login password"));
    $cli->writeln();
}
